==> libgda3_3.0.2.orig.tar.gz: libgda-3.0.2/providers/oracle/gda-oracle-recordset.h <==
/* GDA Oracle provider
 * Copyright (C) 2002 - 2004 The GNOME Foundation.
 *
 * AUTHORS:
 * 	Tim Coleman <tim@timcoleman.com>
 *
 * Borrowed from mysql-oracle-recordset.h, written by
 *      Michael Lausch <michael@lausch.at>
 *	Rodrigo Moya <rodrigo@gnome-db.org>
 *      Vivien Malerba <malerba@gnome-db.org>
 *
 * This Library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This Library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this Library; see the file COPYING.LIB.  If not,
 * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef __GDA_ORACLE_RECORDSET_H__
#define __GDA_ORACLE_RECORDSET_H__

#include <libgda/gda-data-model-hash.h>
#include <libgda/gda-value.h>
#include <oci.h>

G_BEGIN_DECLS

#define GDA_TYPE_ORACLE_RECORDSET            (gda_oracle_recordset_get_type())
#define GDA_ORACLE_RECORDSET(obj)            (G_TYPE_CHECK_INSTANCE_CAST (obj, GDA_TYPE_ORACLE_RECORDSET, GdaOracleRecordset))
#define GDA_ORACLE_RECORDSET_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST (klass, GDA_TYPE_ORACLE_RECORDSET, GdaOracleRecordsetClass))
#define GDA_IS_ORACLE_RECORDSET(obj)         (G_TYPE_CHECK_INSTANCE_TYPE (obj, GDA_TYPE_ORACLE_RECORDSET))
#define GDA_IS_ORACLE_RECORDSET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GDA_TYPE_ORACLE_RECORDSET))


typedef struct _GdaOracleRecordset        GdaOracleRecordset;
typedef struct _GdaOracleRecordsetClass   GdaOracleRecordsetClass;
typedef struct _GdaOracleRecordsetField   GdaOracleRecordsetField;
typedef struct _GdaOracleRecordsetPrivate GdaOracleRecordsetPrivate;
typedef struct _GdaOracleValue            GdaOracleValue;

struct _GdaOracleRecordset {
	GdaDataModelRow model;
	GdaOracleRecordsetPrivate *priv;
};

struct _GdaOracleRecordsetClass {
	GdaDataModelRowClass parent_class;
};

struct _GdaOracleValue {
	OCIDefine *hdef;
	OCIParam *pard;
	sb2 indicator;
	ub2 sql_type;
	ub2 defined_size;
	gpointer value;
	GType g_type;
};


GType               gda_oracle_recordset_get_type (void);
GdaOracleRecordset *gda_oracle_recordset_new (GdaConnection *cnc, GdaOracleConnectionData *cdata, 
					      OCIStmt *stmthp, GArray *col_size_array);

G_END_DECLS

#endif

==> libgda-4.2.2.tar.gz: libgda-4.2.2/providers/oracle/gda-oracle-recordset.h <==
/* GDA Oracle provider
 * Copyright (C) 2009 The GNOME Foundation.
 *
 * AUTHORS:
 *      Vivien Malerba <malerba@gnome-db.org>
 *
 * This Library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This Library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this Library; see the file COPYING.LIB.  If not,
 * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef __GDA_ORACLE_RECORDSET_H__
#define __GDA_ORACLE_RECORDSET_H__

#include <libgda/libgda.h>
#include <providers-support/gda-data-select-priv.h>
#include "gda-oracle-pstmt.h"

G_BEGIN_DECLS

#define GDA_TYPE_ORACLE_RECORDSET            (gda_oracle_recordset_get_type())
#define GDA_ORACLE_RECORDSET(obj)            (G_TYPE_CHECK_INSTANCE_CAST (obj, GDA_TYPE_ORACLE_RECORDSET, GdaOracleRecordset))
#define GDA_ORACLE_RECORDSET_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST (klass, GDA_TYPE_ORACLE_RECORDSET, GdaOracleRecordsetClass))
#define GDA_IS_ORACLE_RECORDSET(obj)         (G_TYPE_CHECK_INSTANCE_TYPE (obj, GDA_TYPE_ORACLE_RECORDSET))
#define GDA_IS_ORACLE_RECORDSET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GDA_TYPE_ORACLE_RECORDSET))

typedef struct _GdaOracleRecordset        GdaOracleRecordset;
typedef struct _GdaOracleRecordsetClass   GdaOracleRecordsetClass;
typedef struct _GdaOracleRecordsetPrivate GdaOracleRecordsetPrivate;

struct _GdaOracleRecordset {
	GdaDataSelect                model;
	GdaOracleRecordsetPrivate *priv;
};

struct _GdaOracleRecordsetClass {
	GdaDataSelectClass             parent_class;
};

GType         gda_oracle_recordset_get_type  (void) G_GNUC_CONST;
GdaDataModel *gda_oracle_recordset_new       (GdaConnection *cnc, GdaOraclePStmt *ps, GdaSet *exec_params,
					      GdaDataModelAccessFlags flags, GType *col_types);

G_END_DECLS

#endif
